---
title: Ansible Wiki ELK Re-Indexing
tags:
- ansible
---
# Re-index ElasticSearch Index

Sometimes an index gets broken and here is how this can be repaired following
this [great guide](https://www.thirdrocktechkno.com/blog/6-steps-to-reindex-elasticsearch-data)

We use `$IDX` for the existing, e.g. broken index and `$IDXNEW` for the new one.

## Show number of records for all indexes

```shell
curl -X GET 'http://${ELUSER}:${ELPASS}@localhost:9200//_cat/indices/%2A?v=&s=index:desc'
```

## Create new index with mappings

```shell
curl -X PUT http://${ELUSER}:${ELPASS}@localhost:9200/$IDXNEW \
  -H 'Content-Type: application/json' \
  -d '{
    "mappings": {
      "properties": {
        [PROVIDE THE MAPPING HERE]
      }
    }
  }'
```

## Re-index from old to new index

```shell
curl -X POST http://${ELUSER}:${ELPASS}@localhost:9200/_reindex \
  -H 'Content-Type: application/json' \
  -d '{
    "source": {
      "index": "$IDX"
    },
    "dest": {
      "index": "$IDXBEW"
    }
  }'
```

## Delete the old index

```shell
curl -X DELETE http://${ELUSER}:${ELPASS}@localhost:9200/$IDX
```

## Delete and recreate alias

```shell
curl -X POST http://${ELUSER}:${ELPASS}@localhost:9200/_aliases \
  -H 'Content-Type: application/json' \
  -d '{
    "actions": [
      {
        "remove": {
          "index": "$IDXNEW",
          "alias": "$IDX"
        }
      }
    ]
  }'
```

```shell
curl -X POST http://${ELUSER}:${ELPASS}@localhost:9200/_aliases \
  -H 'Content-Type: application/json' \
  -d '{
    "actions": [
      {
        "add": {
          "index": "$IDXNEW",
          "alias": "$IDX"
        }
      }
    ]
  }'
```
